==> org.apache.sling.caconfig.spi-1.3.4-source-release.zip: org.apache.sling.caconfig.spi-1.3.4/src/test/java/org/apache/sling/caconfig/spi/ConfigurationPersistDataTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.caconfig.spi;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertSame;

import java.util.Map;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.runners.MockitoJUnitRunner;

@RunWith(MockitoJUnitRunner.class)
public class ConfigurationPersistDataTest {

    @Mock
    private Map<String,Object> props;

    @Test
    public void testGetProperties() {
        ConfigurationPersistData underTest = new ConfigurationPersistData(props)
                .collectionItemName("item1");
        
        assertSame(props, underTest.getProperties());
        assertEquals("item1", underTest.getCollectionItemName());
    }

}

==> org.apache.sling.caconfig.spi-1.4.0-source-release.zip: org.apache.sling.caconfig.spi-1.4.0/src/test/java/org/apache/sling/caconfig/spi/ConfigurationPersistDataTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.caconfig.spi;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertSame;

import java.util.Map;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;

@RunWith(MockitoJUnitRunner.class)
public class ConfigurationPersistDataTest {

    @Mock
    private Map<String,Object> props;

    @Test
    public void testGetProperties() {
        ConfigurationPersistData underTest = new ConfigurationPersistData(props)
                .collectionItemName("item1");

        assertSame(props, underTest.getProperties());
        assertEquals("item1", underTest.getCollectionItemName());
    }

}
